---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: ''
assignees: ''

---

**Describe the bug:**

A clear and concise description of what the bug is, including what you were
expecting to happen and what actually happened. Please report the version of
crema that you are using and the operating system. Also, please make sure that
you have upgraded to the latest version of crema before submitting the bug
report.

**To Reproduce:**

If at all possible, please provide a snippet of code that can reproduce this
error. It is much easier for us to track down bugs and fix them if we have an
example script that fails until we're successful.
